#-------------------------------------------------------------------------------------------------------------------------------------

# CIS - Community Innovation Survey 2008 - Data without Boundaries (Work Package 5)

# This routine processes CIS 2008 Ireland data formatted in CSV.
# Checked for the July 2013 release of the CIS, as provided by Eurostat.

# Version 1 of the routine, March 2015
# R 3.1.3

# University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project
# Sebastian Kocar
# http://www.adp.fdv.uni-lj.si/
# Contact: arhiv.podatkov@fdv.uni-lj.si

# This R code is protected under the creative commons license.

#-------------------------------------------------------------------------------------------------------------------------------------


# --- CONFIGURATION SECTION - START ---


# The following command should contain the complete path and
# name of the .csv file to be read (e.g. "C:/CIS 2008/Data/ALL.csv")
# Change CSV_DATA_PATH to your filename, below:

csvpath <- "CSV_DATA_PATH"


# The following command should contain the complete path and
# name of the .Rdata file to be saved (e.g. "C:/CIS 2008/Data/ALL.Rdata")
# Change RDATA_PATH to your filename, below:

rdatapath <- "RDATA_PATH"


# --- CONFIGURATION SECTION -  END  ---

# ------------------------------------------------------------------------------



# There should be nothing to change below this line
# ------------------------------------------------------------------------------



# --- Read the raw data ---

rdatafile <- read.csv(csvpath, sep = ",")

names(rdatafile) <- toupper(names(rdatafile))    # all variable names to upper case


# ------------------------------------------------------------------------------



# --- Recode string variables which have labels, to numeric variables ---

NACE_PRO <- rdatafile[ , "NACE_PRO"]
tempvar <- rep(NA, length(NACE_PRO))

tempvar[NACE_PRO == "A"] <- 1
tempvar[NACE_PRO == "B"] <- 2
tempvar[NACE_PRO == "C10_C12"] <- 3
tempvar[NACE_PRO == "C13_C15"] <- 4
tempvar[NACE_PRO == "C16_C18"] <- 5
tempvar[NACE_PRO == "C19_C23"] <- 6
tempvar[NACE_PRO == "C24_C25"] <- 7
tempvar[NACE_PRO == "C26_C30"] <- 8
tempvar[NACE_PRO == "C31_C33"] <- 9
tempvar[NACE_PRO == "D"] <- 10
tempvar[NACE_PRO == "E"] <- 11
tempvar[NACE_PRO == "F"] <- 12
tempvar[NACE_PRO == "G"] <- 13
tempvar[NACE_PRO == "H49_H51"] <- 14
tempvar[NACE_PRO == "H52_H53"] <- 15
tempvar[NACE_PRO == "I"] <- 16
tempvar[NACE_PRO == "J58_J60"] <- 17
tempvar[NACE_PRO == "J61_J63"] <- 18
tempvar[NACE_PRO == "K"] <- 19
tempvar[NACE_PRO == "L"] <- 20
tempvar[NACE_PRO == "M69_M70"] <- 21
tempvar[NACE_PRO == "M71_M73"] <- 22
tempvar[NACE_PRO == "M74_M75"] <- 23
tempvar[NACE_PRO == "N"] <- 24

rdatafile[ , "NACE_PRO"] <- tempvar


# ------------------------------------------------------------------------------



# --- Set the variable labels attribute --- 

attr(rdatafile, "variable labels") <- list(
"ID"       = "Name of the enterprise",
"COUNTRY"  = "Country of enterprise",
"NACE_PRO" = "Main activity",
"GP"       = "Enterprise part of a group",
"C_HO"     = "Country of head office",
"MARLOC"   = "Local/regional market (within country)",
"MARNAT"   = "National market (other regions of country)",
"MAREUR"   = "Other EU/EFTA/CC market",
"MAROTH"   = "All other countries",
"INPDGD"   = "Introduced onto the market a new or significantly improved good",
"INPDSV"   = "Introduced onto the market a new or significantly improved service",
"NEWMKT"   = "Did the enterprise introduce a product new to the market",
"NEWFRM"   = "Did the enterprise introduce a product new to the firm",
"TURNMAR"  = "% of turnover in new or improved products introduced during 2006-2008 that were new to the market",
"TURNIN"   = "% of turnover in new or improved products introduced during 2006-2008 that were only new to the firm",
"TURNUNG"  = "% of turnover in  unchanged or marginally modified products during 2006-2008",
"INPSPD"   = "Introduced onto the market a new or significantly improved method of production",
"INPSLG"   = "Introduced onto the market a new or significantly improved logistic, delivery or distribution system",
"INPSSU"   = "Introduced onto the market a new or significantly improved supporting activities",
"INABA"    = "Abandoned or suspended before completion",
"INONG"    = "Still ongoing at the end of the 2008",
"RRDIN"    = "Engagement in intramural R&D",
"RRDEX"    = "Engagement in extramural R&D",
"RMAC"     = "Engagement in acquisition of machinery",
"ROEK"     = "Engagement in acquisition of external knowledge",
"RRDINXM"  = "Expenditure in intramural R&D",
"RRDEXXM"  = "Purchase of extramural R&D",
"RMACXM"   = "Expenditure in acquisition of machinery",
"ROEKXM"   = "Expenditure in acquisition of external knowledge",
"RTOT_MSK" = "Total of these four innovation expenditure categories",
"CO"       = "Cooperation arrangements on innovation activities",
"CO11"     = "Other enterprises within enterprise group : National",
"CO12"     = "Other enterprises within enterprise group : EU/EFTA/EU-CC",
"CO13"     = "Other enterprises within enterprise group : US",
"CO14"     = "Other enterprises within enterprise group : China or India",
"CO15"     = "Other enterprises within enterprise group : Other countries",
"CO21"     = "Suppliers of equipment, etc. : National",
"CO22"     = "Suppliers of equipment, etc. : EU/EFTA/EU-CC",
"CO23"     = "Suppliers of equipment, etc. : US",
"CO24"     = "Suppliers of equipment, etc. : China or India",
"CO25"     = "Suppliers of equipment, etc. :  Other countries",
"CO31"     = "Clients or customers : National",
"CO32"     = "Clients or customers : EU/EFTA/EU-CC",
"CO33"     = "Clients or customers : US",
"CO34"     = "Clients or customers : China or India",
"CO35"     = "Clients or customers : Other countries",
"CO41"     = "Competitors or other firms  : National",
"CO42"     = "Competitors or other firms  : EU/EFTA/EU-CC",
"CO43"     = "Competitors or other firms  : US",
"CO44"     = "Competitors or other firms  : China or India",
"CO45"     = "Competitors or other firms  : Other countries",
"CO51"     = "Consultants, commercial labs, private R&D institutes : National",
"CO52"     = "Consultants, commercial labs, private R&D institutes : EU/EFTA/EU-CC",
"CO53"     = "Consultants, commercial labs, private R&D institutes : US",
"CO54"     = "Consultants, commercial labs, private R&D institutes : China or India",
"CO55"     = "Consultants, commercial labs, private R&D institutes : Other countries",
"CO61"     = "Universities or other  : National",
"CO62"     = "Universities or other  : EU/EFTA/EU-CC",
"CO63"     = "Universities or other  : US",
"CO64"     = "Universities or other  : China or India",
"CO65"     = "Universities or other  : Other countries",
"CO71"     = "Government or public research institutes: National",
"CO72"     = "Government or public research institutes:  EU/EFTA/EU-CC",
"CO73"     = "Government or public research institutes: US",
"CO74"     = "Government or public research institutes: China or India",
"CO75"     = "Government or public research institutes: Other countries",
"ORANGE"   = "Increased range of goods or services",
"OREPL"    = "Replace outdated products or processes",
"OENMK"    = "Enter new markets",
"OIMKS"    = "Increase market share",
"OQUA"     = "Improve quality of goods or services",
"OFLEX"    = "Improve flexibility for producing goods or services",
"OCAP"     = "Increase capacity for producing goods or services",
"OHES"     = "Improve health and safety",
"OLBR"     = "Reduce labour costs per unit output",
"ORGBUP"   = "New business practices for organising work or procedures",
"ORGWKP"   = "New methods of workplace organisation",
"ORGEXR"   = "New methods of organising external relations",
"ORORED"   = "Reduce time to respond to customer or supplier needs",
"OROABL"   = "Improve ability to develop new products or processes",
"OROQUA"   = "Improve quality of your goods or services",
"ORORCO"   = "Reduce costs per unit output",
"OROCIN"   = "Improved communication or information sharing",
"MKTDGP"   = "Significant changes to the aesthetic design or packaging",
"MKTPDP"   = "New media or techniques for product promotion",
"MKTPDL"   = "New methods for product placement or sales channels",
"MKTPRI"   = "New methods of pricing goods or services",
"OMKTS"    = "Increase or maintain market share",
"OMKTCG"   = "Introduce products to new customer groups",
"OMKTGM"   = "Introduce products to new geographic markets",
"ECOMAT"   = "Reduced material use per unit of output",
"ECOEN"    = "Reduced energy use per unit of output",
"ECOCO"    = "Reduced CO2 footprint (total CO2 production) by your enterprise",
"ECOSUB"   = "Replaced materials with less polluting or hazardous substitutes",
"ECOPOL"   = "Reduced soil, water, noise, or air pollution",
"ECOREC"   = "Recycled waste, water, or materials",
"ECOENU"   = "Reduced energy use",
"ECOPOS"   = "Reduced air, water, soil or noise pollution",
"ECOREA"   = "Improved recycling of product after use",
"ENREG"    = "Existing environmental regulations or taxes on pollution",
"ENREGF"   = "Environmental regulations or taxes that you expected to be introduced in the future",
"ENGRA"    = "Availability of government grants, subsidies or other financial incentives for environmental innovation",
"ENDEM"    = "Current or expected market demand from your customers for environmental innovations",
"ENAGR"    = "Voluntary codes or agreements for environmental good practice within your sector",
"ENVID"    = "Procedures in place to regularly identify and reduce enterprises environmental impacts",
"TURN08M"  = "Total turnover in 2008",
"SIZE06"   = "Total number of employees in 2006",
"SIZE08"   = "Total number of employees in 2008",
"GFTURN"   = "Weight, based the turnover",
"GFENT"    = "Weight, based on the number of enterprises",
"GFEMP"    = "Weight, based on the employment")


# ------------------------------------------------------------------------------



# --- Set the value labels attribute --- 

attr(rdatafile, "value labels") <- vector(mode="list", length=97)

attr(rdatafile, "value labels")[1:75] <- rep(list(c(
    "No" = 0,
    "Yes" = 1
)), 75)

names(attr(rdatafile, "value labels"))[1:75] <- c(
    "GP", "MARLOC", "MARNAT", "MAREUR", "MAROTH", "INPDGD", "INPDSV", "NEWMKT", "NEWFRM",
    "INPSPD", "INPSLG", "INPSSU", "INABA", "INONG", "RRDIN", "RRDEX", "RMAC", "ROEK",
    "CO", "CO11", "CO12", "CO13", "CO14", "CO15", "CO21", "CO22", "CO23", "CO24", "CO25",
    "CO31", "CO32", "CO33", "CO34", "CO35", "CO41", "CO42", "CO43", "CO44", "CO45", "CO51",
    "CO52", "CO53", "CO54", "CO55", "CO61", "CO62", "CO63", "CO64", "CO65", "CO71", "CO72",
    "CO73", "CO74", "CO75", "ORGBUP", "ORGWKP", "ORGEXR", "MKTDGP", "MKTPDP", "MKTPDL",
    "MKTPRI", "ECOMAT", "ECOEN", "ECOCO", "ECOSUB", "ECOPOL", "ECOREC", "ECOENU", "ECOPOS",
    "ECOREA", "ENREG", "ENREGF", "ENGRA", "ENDEM", "ENAGR"
)

attr(rdatafile, "value labels")[76] <- list(c(
    "No answer" = 0,
    "Home country" = 1,
    "EU, EFTA, CC" = 2,
    "rest of world" = 3
))

names(attr(rdatafile, "value labels"))[76] <- "C_HO"

attr(rdatafile, "value labels")[77:93] <- rep(list(c(
    "Not relevant" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
)), 17)

names(attr(rdatafile, "value labels"))[77:93] <- c(
    "ORANGE", "OREPL", "OENMK", "OIMKS", "OQUA", "OFLEX", "OCAP", "OHES", "OLBR", "ORORED",
    "OROABL", "OROQUA", "ORORCO", "OROCIN", "OMKTS", "OMKTCG", "OMKTGM"
)

attr(rdatafile, "value labels")[94] <- list(c(
    "No" = 0,
    "Yes: Implemented before January 2006" = 1,
    "Yes: Implemented or significantly improved after January 2006" = 2,
    "Yes for both before and after January 2006" = 3
))

names(attr(rdatafile, "value labels"))[94] <- "ENVID"

attr(rdatafile, "value labels")[95:96] <- rep(list(c(
    "<50" = 0,
    "50-249" = 1,
    ">=250" = 2
)), 2)

names(attr(rdatafile, "value labels"))[95:96] <- c(
    "SIZE06", "SIZE08"
)

attr(rdatafile, "value labels")[97] <- list(c(
    "Agriculture, forestry and fishing" = 1,
    "Mining and quarrying" = 2,
    "Manufacture of food products, beverages and tobacco products" = 3,
    "Manufacture of textiles, apparel, leather and related products" = 4,
    "Manufacture of wood and paper products, and printing" = 5,
    "Manufacture of coke, refined petroleum products, chemicals, pharmaceuticals, rubber, plastic&other non-metallic products" = 6,
    "Manufacture of basic metals and fabricated metal products, except machinery and equipment" = 7,
    "Manufacture of computer, electronic, optical products, electrical equipment, machinery, transport and n.e.c. equipment " = 8,
    "Other manufacturing, and repair and installation of machinery and equipment" = 9,
    "Electricity, gas, steam and air-conditioning supply" = 10,
    "Water supply, sewerage, waste management and remediation" = 11,
    "Construction" = 12,
    "Wholesale and retail trade, repair of motor vehicles and motorcycles" = 13,
    "Land transport and transport via pipelines, water transport and air transport" = 14,
    "Warehousing and support activities for transportation, postal and courier activities" = 15,
    "Accommodation and food service activities" = 16,
    "Publishing, audiovisual and broadcasting activities" = 17,
    "Telecommunications, IT and other information services" = 18,
    "Financial and insurance activities" = 19,
    "Real estate activities" = 20,
    "Legal and accounting activities, Activities of head offices, management consultancy activities" = 21,
    "Architectural, engineering activities, scientific research, development, advertising, market research" = 22,
    "Other professional, scientific and technical activities, veterinary activities" = 23,
    "Administrative and support service activities" = 24
))

names(attr(rdatafile, "value labels"))[97] <- "NACE_PRO"


# ------------------------------------------------------------------------------



# --- Save the R data file --- 

rfilename <- unlist(strsplit(basename(rdatapath), split="\\."))[1]
rdatapath <- file.path(dirname(rdatapath), paste(rfilename, ".Rdata", sep=""))
assign(rfilename, rdatafile)
eval(parse(text = paste("save(", rfilename, ", file=rdatapath)", sep="")))


# ------------------------------------------------------------------------------



# --- Clean up the working space --- 

rm(rfilename, rdatafile, csvpath, rdatapath, tempvar, NACE_PRO)


# ------------------------------------------------------------------------------



