#-------------------------------------------------------------------------------------------------------------------------------------

# CIS - Community Innovation Survey 2008 - Data without Boundaries (Work Package 5)

# This routine processes CIS 2008 Italy data formatted in CSV.
# Checked for the July 2013 release of the CIS, as provided by Eurostat.

# Version 1 of the routine, March 2015
# R 3.1.3

# University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project
# Sebastian Kocar
# http://www.adp.fdv.uni-lj.si/
# Contact: arhiv.podatkov@fdv.uni-lj.si

# This R code is protected under the creative commons license.

#-------------------------------------------------------------------------------------------------------------------------------------


# --- CONFIGURATION SECTION - START ---


# The following command should contain the complete path and
# name of the .csv file to be read (e.g. "C:/CIS 2008/Data/ALL.csv")
# Change CSV_DATA_PATH to your filename, below:

csvpath <- "CSV_DATA_PATH"


# The following command should contain the complete path and
# name of the .Rdata file to be saved (e.g. "C:/CIS 2008/Data/ALL.Rdata")
# Change RDATA_PATH to your filename, below:

rdatapath <- "RDATA_PATH"


# --- CONFIGURATION SECTION -  END  ---

# ------------------------------------------------------------------------------



# There should be nothing to change below this line
# ------------------------------------------------------------------------------



# --- Read the raw data ---

rdatafile <- read.csv(csvpath, sep = ",")

names(rdatafile) <- toupper(names(rdatafile))    # all variable names to upper case


# ------------------------------------------------------------------------------



# --- Recode string variables which have labels, to numeric variables ---

LARMAR <- rdatafile[ , "LARMAR"]
tempvar <- rep(NA, length(LARMAR))

tempvar[LARMAR == "A"] <- 1
tempvar[LARMAR == "B"] <- 2
tempvar[LARMAR == "C"] <- 3
tempvar[LARMAR == "D"] <- 4

rdatafile[ , "LARMAR"] <- tempvar

PMOS <- rdatafile[ , "PMOS"]
tempvar <- rep(NA, length(PMOS))

tempvar[PMOS == "A"] <- 1
tempvar[PMOS == "B"] <- 2
tempvar[PMOS == "C"] <- 3
tempvar[PMOS == "D"] <- 4
tempvar[PMOS == "E"] <- 5
tempvar[PMOS == "F"] <- 6
tempvar[PMOS == "G"] <- 7

rdatafile[ , "PMOS"] <- tempvar

NACE <- rdatafile[ , "NACE"]
tempvar <- rep(NA, length(NACE))

tempvar[NACE == "B"] <- 1
tempvar[NACE == "10"] <- 2
tempvar[NACE == "12-No"] <- 3
tempvar[NACE == "13"] <- 4
tempvar[NACE == "14"] <- 5
tempvar[NACE == "15"] <- 6
tempvar[NACE == "16"] <- 7
tempvar[NACE == "17"] <- 8
tempvar[NACE == "18"] <- 9
tempvar[NACE == "19"] <- 10
tempvar[NACE == "20"] <- 11
tempvar[NACE == "21"] <- 12
tempvar[NACE == "22"] <- 13
tempvar[NACE == "23"] <- 14
tempvar[NACE == "24"] <- 15
tempvar[NACE == "25"] <- 16
tempvar[NACE == "26"] <- 17
tempvar[NACE == "27"] <- 18
tempvar[NACE == "28"] <- 19
tempvar[NACE == "29"] <- 20
tempvar[NACE == "30"] <- 21
tempvar[NACE == "31"] <- 22
tempvar[NACE == "32"] <- 23
tempvar[NACE == "33"] <- 24
tempvar[NACE == "35"] <- 25
tempvar[NACE == "36"] <- 26
tempvar[NACE == "37"] <- 27
tempvar[NACE == "38-39"] <- 28
tempvar[NACE == "41"] <- 29
tempvar[NACE == "42"] <- 30
tempvar[NACE == "43"] <- 31
tempvar[NACE == "45"] <- 32
tempvar[NACE == "46"] <- 33
tempvar[NACE == "47"] <- 34
tempvar[NACE == "49"] <- 35
tempvar[NACE == "50"] <- 36
tempvar[NACE == "51"] <- 37
tempvar[NACE == "52"] <- 38
tempvar[NACE == "53"] <- 39
tempvar[NACE == "55"] <- 40
tempvar[NACE == "56"] <- 41
tempvar[NACE == "58"] <- 42
tempvar[NACE == "59"] <- 43
tempvar[NACE == "61"] <- 44
tempvar[NACE == "62"] <- 45
tempvar[NACE == "63"] <- 46
tempvar[NACE == "64"] <- 47
tempvar[NACE == "65"] <- 48
tempvar[NACE == "66"] <- 49
tempvar[NACE == "68"] <- 50
tempvar[NACE == "71"] <- 51
tempvar[NACE == "72"] <- 52
tempvar[NACE == "77"] <- 53

rdatafile[ , "NACE"] <- tempvar

EMP06 <- rdatafile[ , "EMP06"]
tempvar <- rep(NA, length(EMP06))

tempvar[EMP06 == "10_49"] <- 1
tempvar[EMP06 == "50-249"] <- 2
tempvar[EMP06 == "250+"] <- 3
tempvar[EMP06 == "50+"] <- 4
tempvar[EMP06 == "ALL"] <- 5

rdatafile[ , "EMP06"] <- tempvar

EMP08 <- rdatafile[ , "EMP08"]
tempvar <- rep(NA, length(EMP08))

tempvar[EMP08 == "10_49"] <- 1
tempvar[EMP08 == "50-249"] <- 2
tempvar[EMP08 == "250+"] <- 3
tempvar[EMP08 == "50+"] <- 4
tempvar[EMP08 == "ALL"] <- 5

rdatafile[ , "EMP08"] <- tempvar


# ------------------------------------------------------------------------------



# --- Set the variable labels attribute --- 

attr(rdatafile, "variable labels") <- list(
"ID"       = "Name of the enterprise",
"GP"       = "Enterprise part of a group",
"MARLOC"   = "Local/regional market (within country)",
"MARNAT"   = "National market (other regions of country)",
"MAREUR"   = "Other EU/EFTA/CC market",
"MAROTH"   = "All other countries",
"LARMAR"   = "Largest market in terms of turnover between 2006 and 2008",
"INPDGD"   = "Introduced onto the market a new or significantly improved good",
"INPDSV"   = "Introduced onto the market a new or significantly improved service",
"INPDTW"   = "Who mainly developed these products",
"NEWMKT"   = "Did the enterprise introduce a product new to the market",
"NEWFRM"   = "Did the enterprise introduce a product new to the firm",
"TURNMAR"  = "% of turnover in new or improved products introduced during 2006-2008 that were new to the market",
"TURNIN"   = "% of turnover in new or improved products introduced during 2006-2008 that were only new to the firm",
"TURNUNG"  = "% of turnover in  unchanged or marginally modified products during 2006-2008",
"INPSPD"   = "Introduced onto the market a new or significantly improved method of production",
"INPSLG"   = "Introduced onto the market a new or significantly improved logistic, delivery or distribution system",
"INPSSU"   = "Introduced onto the market a new or significantly improved supporting activities",
"INPCSW"   = "Who mainly developed these processes",
"INPSNM"   = "Were any of your process innovations introduced between 2006 and 2008 new to your market",
"INABA"    = "Abandoned or suspended before completion",
"INONG"    = "Still ongoing at the end of the 2008",
"RRDIN"    = "Engagement in intramural R&D",
"RDENG"    = "Type of engagement in R&D",
"RRDEX"    = "Engagement in extramural R&D",
"RMAC"     = "Engagement in acquisition of machinery",
"ROEK"     = "Engagement in acquisition of external knowledge",
"RTR"      = "Engagement in training for innovative activities",
"RMAR"     = "Engagement in market introduction of innovation",
"RPRE"     = "Engagement in other preparation",
"FUNLOC"   = "Public funding from local or regional authorities",
"FUNGMT"   = "Public funding from central government",
"FUNEU"    = "Public funding from the EU",
"FUNRTD"   = "Funding from EU's 4th, 5th, 6th or 7th Framework Programme for RTD",
"SENTG"    = "Sources from within the enterprise",
"SSUP"     = "Sources from Suppliers of equipment, materials, etc.",
"SCLI"     = "Sources from Clients or customers",
"SCOM"     = "Sources from Competitors and other enterprises of same industry",
"SINS"     = "Sources from consultants, commercial labs or private R&D institutes",
"SUNI"     = "Sources from Universities or other higher education institutes",
"SGMT"     = "Sources from Government or public research institutes",
"SCON"     = "Sources from professional conferences, trade fairs, meetings",
"SJOU"     = "Sources from Scientific journals, trade/scientific publications",
"SPRO"     = "Sources from Professional and industry associations",
"CO"       = "Cooperation arrangements on innovation activities",
"CO11"     = "Other enterprises within enterprise group : National",
"CO12"     = "Other enterprises within enterprise group : EU/EFTA/EU-CC",
"CO13"     = "Other enterprises within enterprise group : US",
"CO14"     = "Other enterprises within enterprise group : China or India",
"CO15"     = "Other enterprises within enterprise group : Other countries",
"CO21"     = "Suppliers of equipment, etc. : National",
"CO22"     = "Suppliers of equipment, etc. : EU/EFTA/EU-CC",
"CO23"     = "Suppliers of equipment, etc. : US",
"CO24"     = "Suppliers of equipment, etc. : China or India",
"CO25"     = "Suppliers of equipment, etc. :  Other countries",
"CO31"     = "Clients or customers : National",
"CO32"     = "Clients or customers : EU/EFTA/EU-CC",
"CO33"     = "Clients or customers : US",
"CO34"     = "Clients or customers : China or India",
"CO35"     = "Clients or customers : Other countries",
"CO41"     = "Competitors or other firms  : National",
"CO42"     = "Competitors or other firms  : EU/EFTA/EU-CC",
"CO43"     = "Competitors or other firms  : US",
"CO44"     = "Competitors or other firms  : China or India",
"CO45"     = "Competitors or other firms  : Other countries",
"CO51"     = "Consultants, commercial labs, private R&D institutes : National",
"CO52"     = "Consultants, commercial labs, private R&D institutes : EU/EFTA/EU-CC",
"CO53"     = "Consultants, commercial labs, private R&D institutes : US",
"CO54"     = "Consultants, commercial labs, private R&D institutes : China or India",
"CO55"     = "Consultants, commercial labs, private R&D institutes : Other countries",
"CO61"     = "Universities or other  : National",
"CO62"     = "Universities or other  : EU/EFTA/EU-CC",
"CO63"     = "Universities or other  : US",
"CO64"     = "Universities or other  : China or India",
"CO65"     = "Universities or other  : Other countries",
"CO71"     = "Government or public research institutes: National",
"CO72"     = "Government or public research institutes:  EU/EFTA/EU-CC",
"CO73"     = "Government or public research institutes: US",
"CO74"     = "Government or public research institutes: China or India",
"CO75"     = "Government or public research institutes: Other countries",
"PMOS"     = "Most important co-operation partner",
"ORANGE"   = "Increased range of goods or services",
"OREPL"    = "Replace outdated products or processes",
"OENMK"    = "Enter new markets",
"OIMKS"    = "Increase market share",
"OQUA"     = "Improve quality of goods or services",
"OFLEX"    = "Improve flexibility for producing goods or services",
"OCAP"     = "Increase capacity for producing goods or services",
"OHES"     = "Improve health and safety",
"OLBR"     = "Reduce labour costs per unit output",
"ORGBUP"   = "New business practices for organising work or procedures",
"ORGWKP"   = "New methods of workplace organisation",
"ORGEXR"   = "New methods of organising external relations",
"ORORED"   = "Reduce time to respond to customer or supplier needs",
"OROABL"   = "Improve ability to develop new products or processes",
"OROQUA"   = "Improve quality of your goods or services",
"ORORCO"   = "Reduce costs per unit output",
"OROCIN"   = "Improved communication or information sharing",
"MKTDGP"   = "Significant changes to the aesthetic design or packaging",
"MKTPDP"   = "New media or techniques for product promotion",
"MKTPDL"   = "New methods for product placement or sales channels",
"MKTPRI"   = "New methods of pricing goods or services",
"OMKTS"    = "Increase or maintain market share",
"OMKTCG"   = "Introduce products to new customer groups",
"OMKTGM"   = "Introduce products to new geographic markets",
"ECOMAT"   = "Reduced material use per unit of output",
"ECOEN"    = "Reduced energy use per unit of output",
"ECOCO"    = "Reduced CO2 footprint (total CO2 production) by your enterprise",
"ECOSUB"   = "Replaced materials with less polluting or hazardous substitutes",
"ECOPOL"   = "Reduced soil, water, noise, or air pollution",
"ECOREC"   = "Recycled waste, water, or materials",
"ECOENU"   = "Reduced energy use",
"ECOPOS"   = "Reduced air, water, soil or noise pollution",
"ECOREA"   = "Improved recycling of product after use",
"ENREG"    = "Existing environmental regulations or taxes on pollution",
"ENREGF"   = "Environmental regulations or taxes that you expected to be introduced in the future",
"ENGRA"    = "Availability of government grants, subsidies or other financial incentives for environmental innovation",
"ENDEM"    = "Current or expected market demand from your customers for environmental innovations",
"ENAGR"    = "Voluntary codes or agreements for environmental good practice within your sector",
"ENVID"    = "Procedures in place to regularly identify and reduce enterprises environmental impacts",
"WEIGHT"   = "Weight",
"NUTS"     = "Country of enterprise",
"NACE"     = "Main activity",
"HO"       = "Country of head office",
"RRDINX"   = "Expenditure in intramural R&D",
"RRDEXX"   = "Purchase of extramural R&D",
"RMACX"    = "Expenditure in acquisition of machinery",
"ROEKX"    = "Expenditure in acquisition of external knowledge",
"RTRX"     = "Expenditure in training",
"RPREX"    = "Expenditure in other preparation",
"RMARX"    = "Expenditure in market introduction of innovation",
"RTOT"     = "Unknown weight variable, maybe based on nr. of employees?",
"TURN06"   = "Total turnover in 2006",
"TURN08"   = "Total turnover in 2008",
"EMP06"    = "Total number of employees in 2006",
"EMP08"    = "Total number of employees in 2008",
"WEIGHTNR" = "Weights corrected for non-response bias")


# ------------------------------------------------------------------------------



# --- Set the value labels attribute --- 

attr(rdatafile, "value labels") <- vector(mode="list", length=120)

attr(rdatafile, "value labels")[1:82] <- rep(list(c(
    "No" = 0,
    "Yes" = 1
)), 82)

names(attr(rdatafile, "value labels"))[1:82] <- c(
    "GP", "MARLOC", "MARNAT", "MAREUR", "MAROTH", "INPDGD", "INPDSV", "NEWMKT", "NEWFRM",
    "INPSPD", "INPSLG", "INPSSU", "INABA", "INONG", "RRDIN", "RRDEX", "RMAC", "ROEK",
    "RTR", "RMAR", "RPRE", "FUNLOC", "FUNGMT", "FUNEU", "FUNRTD", "CO", "CO11", "CO12",
    "CO13", "CO14", "CO15", "CO21", "CO22", "CO23", "CO24", "CO25", "CO31", "CO32", "CO33",
    "CO34", "CO35", "CO41", "CO42", "CO43", "CO44", "CO45", "CO51", "CO52", "CO53", "CO54",
    "CO55", "CO61", "CO62", "CO63", "CO64", "CO65", "CO71", "CO72", "CO73", "CO74", "CO75",
    "ORGBUP", "ORGWKP", "ORGEXR", "MKTDGP", "MKTPDP", "MKTPDL", "MKTPRI", "ECOMAT", "ECOEN",
    "ECOCO", "ECOSUB", "ECOPOL", "ECOREC", "ECOENU", "ECOPOS", "ECOREA", "ENREG", "ENREGF",
    "ENGRA", "ENDEM", "ENAGR"
)

attr(rdatafile, "value labels")[83] <- list(c(
    "Local/regional within [your country]" = 1,
    "National (other regions of [your country])" = 2,
    "Other European Union (EU), EFTA, or EU candidate countries" = 3,
    "All other countries" = 4
))

names(attr(rdatafile, "value labels"))[83] <- "LARMAR"

attr(rdatafile, "value labels")[84:85] <- rep(list(c(
    "Mainly by the enterprise or enterprise group" = 1,
    "In cooperation with other enterprises or institutions" = 2,
    "Mainly other enterprises or institutions" = 3
)), 2)

names(attr(rdatafile, "value labels"))[84:85] <- c(
    "INPDTW", "INPCSW"
)

attr(rdatafile, "value labels")[86] <- list(c(
    "No" = 0,
    "Yes" = 1,
    "Do not know" = 2
))

names(attr(rdatafile, "value labels"))[86] <- "INPSNM"

attr(rdatafile, "value labels")[87] <- list(c(
    "continuously" = 1,
    "occasionally" = 2
))

names(attr(rdatafile, "value labels"))[87] <- "RDENG"

attr(rdatafile, "value labels")[88:97] <- rep(list(c(
    "Not used" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
)), 10)

names(attr(rdatafile, "value labels"))[88:97] <- c(
    "SENTG", "SSUP", "SCLI", "SCOM", "SINS", "SUNI", "SGMT", "SCON", "SJOU", "SPRO"
)

attr(rdatafile, "value labels")[98] <- list(c(
    "Other enterprises within enterprise group" = 1,
    "Suppliers of equipment, etc" = 2,
    "Clients or customers" = 3,
    "Competitors or other firms" = 4,
    "Consultants, commercial labs, private R&D institutes" = 5,
    "Universities or other" = 6,
    "Government or public research institutes" = 7
))

names(attr(rdatafile, "value labels"))[98] <- "PMOS"

attr(rdatafile, "value labels")[99:115] <- rep(list(c(
    "Not relevant" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
)), 17)

names(attr(rdatafile, "value labels"))[99:115] <- c(
    "ORANGE", "OREPL", "OENMK", "OIMKS", "OQUA", "OFLEX", "OCAP", "OHES", "OLBR", "ORORED",
    "OROABL", "OROQUA", "ORORCO", "OROCIN", "OMKTS", "OMKTCG", "OMKTGM"
)

attr(rdatafile, "value labels")[116] <- list(c(
    "No" = 0,
    "Yes: Implemented before January 2006" = 1,
    "Yes: Implemented or significantly improved after January 2006" = 2,
    "Yes for both before and after January 2006" = 3
))

names(attr(rdatafile, "value labels"))[116] <- "ENVID"

attr(rdatafile, "value labels")[117] <- list(c(
    "Mining and quarrying" = 1,
    "Manufacture of food products" = 2,
    "Manufacture of tobacco products" = 3,
    "Manufacture of textiles" = 4,
    "Manufacture of wearing apparel" = 5,
    "Manufacture of leather and related products" = 6,
    "Manufacture of wood, of products of wood, cork, except furniture; manufacture of articles of straw, plaiting materials" = 7,
    "Manufacture of paper and paper products" = 8,
    "Printing and reproduction of recorded media" = 9,
    "Manufacture of coke and refined petroleum products" = 10,
    "Manufacture of chemicals and chemical products" = 11,
    "Manufacture of basic pharmaceutical products and pharmaceutical preparations" = 12,
    "Manufacture of rubber and plastic products" = 13,
    "Manufacture of other non-metallic mineral products" = 14,
    "Manufacture of basic metals" = 15,
    "Manufacture of fabricated metal products, except machinery and equipment" = 16,
    "Manufacture of computer, electronic and optical products" = 17,
    "Manufacture of electrical equipment" = 18,
    "Manufacture of machinery and equipment n.e.c." = 19,
    "Manufacture of motor vehicles, trailers and semi-trailers" = 20,
    "Manufacture of other transport equipment" = 21,
    "Manufacture of furniture" = 22,
    "Other manufacturing" = 23,
    "Repair and installation of machinery and equipment" = 24,
    "Electricity, gas, steam and air conditioning supply" = 25,
    "Water collection, treatment and supply" = 26,
    "Sewerage" = 27,
    "Waste management and remediation activities" = 28,
    "Construction of buildings" = 29,
    "Civil engineering" = 30,
    "Specialised construction activities" = 31,
    "Wholesale and retail trade and repair of motor vehicles and motorcycles" = 32,
    "Wholesale trade, except of motor vehicles and motorcycles" = 33,
    "Retail trade, except of motor vehicles and motorcycles" = 34,
    "Land transport and transport via pipelines" = 35,
    "Water transport" = 36,
    "Air transport" = 37,
    "Warehousing and support activities for transportation" = 38,
    "Postal and courier activities" = 39,
    "Accommodation" = 40,
    "Food and beverage service activities" = 41,
    "Publishing activities" = 42,
    "Motion picture, video and television programme production, sound recording and music publishing activities" = 43,
    "Telecommunications" = 44,
    "Computer programming, consultancy and related activities" = 45,
    "Information service activities" = 46,
    "Financial service activities, except insurance and pension funding" = 47,
    "Insurance, reinsurance and pension funding, except compulsory social security" = 48,
    "Activities auxiliary to financial services and insurance activities" = 49,
    "Real estate activities" = 50,
    "Architectural and engineering activities; technical testing and analysis" = 51,
    "Scientific research and development" = 52,
    "Rental and leasing activities" = 53
))

names(attr(rdatafile, "value labels"))[117] <- "NACE"

attr(rdatafile, "value labels")[118] <- list(c(
    "No answer" = 0,
    "Home country" = 1,
    "EU, EFTA, CC" = 2,
    "rest of world" = 3
))

names(attr(rdatafile, "value labels"))[118] <- "HO"

attr(rdatafile, "value labels")[119:120] <- rep(list(c(
    "10-49" = 1,
    "50-249" = 2,
    "250+" = 3,
    "50+ (only for NACE 45, 65, 66, 68, 72, 77 and B)" = 4,
    "ALL (only for NACE 53)" = 5
)), 2)

names(attr(rdatafile, "value labels"))[119:120] <- c(
    "EMP06", "EMP08"
)


# ------------------------------------------------------------------------------



# --- Save the R data file --- 

rfilename <- unlist(strsplit(basename(rdatapath), split="\\."))[1]
rdatapath <- file.path(dirname(rdatapath), paste(rfilename, ".Rdata", sep=""))
assign(rfilename, rdatafile)
eval(parse(text = paste("save(", rfilename, ", file=rdatapath)", sep="")))


# ------------------------------------------------------------------------------



# --- Clean up the working space --- 

rm(rfilename, rdatafile, csvpath, rdatapath, tempvar, LARMAR, PMOS, NACE, EMP06, EMP08)


# ------------------------------------------------------------------------------



